summaryrefslogtreecommitdiffstats
path: root/tdeui/kdatetbl.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeui/kdatetbl.h')
-rw-r--r--tdeui/kdatetbl.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/tdeui/kdatetbl.h b/tdeui/kdatetbl.h
index 159b32244..04a05804c 100644
--- a/tdeui/kdatetbl.h
+++ b/tdeui/kdatetbl.h
@@ -98,7 +98,7 @@ public:
/**
* The size hint.
*/
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
/**
* Return the result. 0 means no selection (reject()), 1..12 are the
* months.
@@ -289,9 +289,9 @@ public:
* To save some time, the size of the largest used cell content is
* calculated in each paintCell() call, since all calculations have
* to be done there anyway. The size is stored in maxCell. The
* tqsizeHint() simply returns a multiple of maxCell.
*/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
/**
* Set the font size of the date table.
*/
@@ -289,9 +289,9 @@ public:
* calculated in each paintCell() call, since all calculations have
* to be done there anyway. The size is stored in maxCell. The
- * tqsizeHint() simply returns a multiple of maxCell.
+ * sizeHint() simply returns a multiple of maxCell.
*/